@@ -7,8 +7,16 @@ set -e -x
 ARCH=`uname -p`
 echo "arch=$ARCH"
 
+ls /opt/python
+
 for V in "${PYTHON_VERSIONS[@]}"; do
     PYBIN=/opt/python/$V/bin
     rm -rf build/       # Avoid lib build by narrow Python is used by wide python
-    $PYBIN/python setup.py bdist_wheel -p manylinux1_${ARCH}
+    $PYBIN/python -m build -w
+done
+
+cd dist
+for whl in *.whl; do
+    auditwheel repair "$whl"
+    rm "$whl"
 done
