@@ -1,32 +1,33 @@
 #!/usr/bin/env python
 # coding: utf-8
 
+import sys
+import pytest
 from msgpack import packb, unpackb
 
 
+@pytest.mark.skipif(sys.version_info[0] == 2, reason="Python 2 is not supported")
 def test_unpack_buffer():
     from array import array
-    buf = array('b')
-    try:
-        buf.frombytes(packb((b'foo', b'bar')))
-    except AttributeError:  # PY2
-        buf.fromstring(packb((b'foo', b'bar')))
+
+    buf = array("b")
+    buf.frombytes(packb((b"foo", b"bar")))
     obj = unpackb(buf, use_list=1)
-    assert [b'foo', b'bar'] == obj
+    assert [b"foo", b"bar"] == obj
 
 
 def test_unpack_bytearray():
-    buf = bytearray(packb(('foo', 'bar')))
+    buf = bytearray(packb((b"foo", b"bar")))
     obj = unpackb(buf, use_list=1)
-    assert [b'foo', b'bar'] == obj
+    assert [b"foo", b"bar"] == obj
     expected_type = bytes
     assert all(type(s) == expected_type for s in obj)
 
 
 def test_unpack_memoryview():
-    buf = bytearray(packb(('foo', 'bar')))
+    buf = bytearray(packb((b"foo", b"bar")))
     view = memoryview(buf)
     obj = unpackb(view, use_list=1)
-    assert [b'foo', b'bar'] == obj
+    assert [b"foo", b"bar"] == obj
     expected_type = bytes
     assert all(type(s) == expected_type for s in obj)
